@@ -1,7 +1,7 @@
 /*
  * entry.c
  *
- * Copyright (c) 2010-2011, 2014, 2017 The MacPorts Project
+ * Copyright (c) 2010-2011, 2014, 2017-2018 The MacPorts Project
  * Copyright (c) 2007 Chris Pickel <sfiera@macports.org>
  * All rights reserved.
  *
@@ -30,7 +30,7 @@
 #include <config.h>
 #endif
 
-/* required for asprintf(3) on OS X */
+/* required for asprintf(3) on macOS */
 #define _DARWIN_C_SOURCE
 /* required for asprintf(3) on Linux */
 #define _GNU_SOURCE
@@ -397,8 +397,8 @@ static int reg_all_entries(reg_registry* reg, char* query, int query_len,
  * @param [out] errPtr   on error, a description of the error that occurred
  * @return               the number of entries if success; false if failure
  */
-int reg_entry_search(reg_registry* reg, char** keys, char** vals, int key_count,
-        int *strategies, reg_entry*** entries, reg_error* errPtr) {
+int reg_entry_search(reg_registry* reg, const char** keys, const char** vals,
+        int key_count, int *strategies, reg_entry*** entries, reg_error* errPtr) {
     int i;
     char* kwd = " WHERE ";
     char* query;
@@ -533,11 +533,16 @@ int reg_entry_owner(reg_registry* reg, char* path, int cs, reg_entry** entry,
     int lower_bound = 0;
     char *query = NULL;
 
-    asprintf(&query, "SELECT id FROM registry.files WHERE (actual_path = ? %s) AND active",
+    asprintf(&query, "SELECT id FROM registry.files %s WHERE (actual_path = ? %s) AND active",
 #if SQLITE_VERSION_NUMBER >= 3003013
+#if SQLITE_VERSION_NUMBER >= 3006004
+             cs ? "INDEXED BY file_actual" : "INDEXED BY file_actual_nocase",
+#else
+             "",
+#endif
              cs ? "" : "COLLATE NOCASE");
 #else
-             "");
+             "", "");
 #endif
 
     if (!query) {
@@ -595,11 +600,16 @@ sqlite_int64 reg_entry_owner_id(reg_registry* reg, char* path, int cs) {
     sqlite_int64 result = 0;
     char *query = NULL;
 
-    asprintf(&query, "SELECT id FROM registry.files WHERE (actual_path = ? %s) AND active",
+    asprintf(&query, "SELECT id FROM registry.files %s WHERE (actual_path = ? %s) AND active",
 #if SQLITE_VERSION_NUMBER >= 3003013
+#if SQLITE_VERSION_NUMBER >= 3006004
+             cs ? "INDEXED BY file_actual" : "INDEXED BY file_actual_nocase",
+#else
+             "",
+#endif
              cs ? "" : "COLLATE NOCASE");
 #else
-             "");
+             "", "");
 #endif
 
     if (!query) {
